summaryrefslogtreecommitdiffhomepage
path: root/templates/advance_game/screens/screen_gameplay.c
diff options
context:
space:
mode:
Diffstat (limited to 'templates/advance_game/screens/screen_gameplay.c')
-rw-r--r--templates/advance_game/screens/screen_gameplay.c11
1 files changed, 6 insertions, 5 deletions
diff --git a/templates/advance_game/screens/screen_gameplay.c b/templates/advance_game/screens/screen_gameplay.c
index f70ddb09..35428a35 100644
--- a/templates/advance_game/screens/screen_gameplay.c
+++ b/templates/advance_game/screens/screen_gameplay.c
@@ -4,7 +4,7 @@
*
* Gameplay Screen Functions Definitions (Init, Update, Draw, Unload)
*
-* Copyright (c) 2014 Ramon Santamaria (@raysan5)
+* Copyright (c) 2014-2017 Ramon Santamaria (@raysan5)
*
* This software is provided "as-is", without any express or implied warranty. In no event
* will the authors be held liable for any damages arising from the use of this software.
@@ -51,10 +51,11 @@ void UpdateGameplayScreen(void)
{
// TODO: Update GAMEPLAY screen variables here!
- // Press enter to change to ENDING screen
- if (IsKeyPressed(KEY_ENTER))
+ // Press enter or tap to change to ENDING screen
+ if (IsKeyPressed(KEY_ENTER) || IsGestureDetected(GESTURE_TAP))
{
finishScreen = 1;
+ PlaySound(fxCoin);
}
}
@@ -63,8 +64,8 @@ void DrawGameplayScreen(void)
{
// TODO: Draw GAMEPLAY screen here!
DrawRectangle(0, 0, GetScreenWidth(), GetScreenHeight(), PURPLE);
- DrawText("GAMEPLAY SCREEN", 20, 20, 40, MAROON);
- DrawText("PRESS ENTER to JUMP to ENDING SCREEN", 170, 220, 20, MAROON);
+ DrawTextEx(font, "GAMEPLAY SCREEN", (Vector2){ 20, 10 }, font.baseSize*3, 4, MAROON);
+ DrawText("PRESS ENTER or TAP to JUMP to ENDING SCREEN", 130, 220, 20, MAROON);
}
// Gameplay Screen Unload logic